#' @name basename_extended
#' @title Utilities enhancing basename()
#'
#' @description
#' Utilities for getting name of files and extension in another whay than of
#' [tools::file_ext()] and others corresponding functions.
#'
#' @param x character vector, file paths
#'
#' @return character vector of processed files.
#' 
#' @details
#'
#' \code{basename_core()} differs from [tools::file_path_sans_ext()] in this:
#' - [basename()] is first applied
#' - "compounded" extensions are removed. See examples.
#' 
#' @export
#' 
#' @encoding UTF-8
#' @author Frédéric Grelot
#'
#' @examples
#'
#' # equivalent to tools::file_path_sans_ext
#' basename_core("toto.7z")
#' 
#' # different from tools::file_path_sans_ext
#' basename_core("toto.7z.001")
#' basename_core("path/toto.csv")
#' basename_core("path/toto.csv.gz")
#'

basename_core = function(x) {
    x = basename(x)
    pattern = "^(.*?)(\\.[[:alnum:]]+){1,2}$"
    sub(pattern, "\\1", basename(x))
}

#' @rdname basename_extended
#'
#' @details
#'
#' \code{basename_ext()} differs from [tools::file_path_sans_ext()] in this:
#' - [basename()] is first applied
#' - "compounded" extensions are extracted. See examples.
#'
#' @export
#'
#' @examples
#'
#' # equivalent to tools::file__ext
#' basename_ext("toto.7z")
#' basename_ext("path/toto.csv")
#' 
#' #'different from tools::file__ext
#' basename_ext("toto.7z.001")
#' basename_ext("path/toto.csv.gz")

basename_ext = function(x) {
    x = basename(x)
    pattern = "^.*?((\\.[[:alnum:]]+){1,2})$"
    result = sub("^\\.", "", sub(pattern, "\\1", x))
    result[!grepl(pattern, x)] = ""
    return(result)
}