#' @title Define path depending on who is logged
#' 
#' @description
#' Depending on logname (linux), a path is defined. If what is mentionned, it
#' is appended through file.path.
#'
#' @param what character, some local paths to be specified.
#' @param who character, typically result of logname.
#'
#' @return Character, path.
#'
#' @export
#'
#' @encoding UTF-8
#' @author Frédéric Grelot
#' 
#' @examples
#'
#' \dontrun{
#' define_path("toto") 
#' define_path("floodam", "toto")
#' }

define_path = function(what, who = system("logname", intern = TRUE)) {
    result = switch(
        EXPR = who,
        "keluo" = "~/data/data-local",
        "floodam" = "~/floodam-data3/data-floodam",
        stop(sprintf("Unknown user (%s)", who))
    )

    if (missing(what)) {
        return(result)
    } else {
        return(file.path(result, what))
    }
}
