#' @title Download PPR 
#'
#' @description
#' Function used to downlaod PPR
#'
#' @param destination character, the address where dara are stocked
#' @param origin character, keyword or the address from where data are downloaded
#' @param name character, vector of acceptable names fo archive to be downloaded
#' @param extension character, vector of acceptable types of archive to be downloaded
#' @param version character, version of archive to be downloaded
#' @param date string, version of archive to be downloaded
#' @param verbose logical, should the function send somme messages while running.
#'
#' @return nothing
#'
#' @export
#'
#' @examples
#' 
#' \dontrun{
#'  destination = tempdir()
#'  download.ppr(destination, version = "34")
#'  unlink(destination)
#' }

download.ppr = function(
    destination,
    origin = "cquest",
    name = NULL,
    extension = NULL,
    version = NULL,
    date = NULL,
    verbose = TRUE) {
    if (origin == "cquest") {
        origin = "https://data.cquest.org/georisques/ppr"
        if (is.null(extension)) extension = c("zip")
    }

    to_do = data.frame(
        origin = origin,
        destination = destination,
        short = "download.admin_express",
        stringsAsFactors = FALSE
    )

    download_archive(to_do, extension = extension, name = name, date = date, version = version, verbose = verbose)
}