#' Format difftime in a convenient way
#'
#' @param x difftime
#'
#' @return formatted difftime
#'
#' @export fmt
#'
#' @encoding UTF-8
#' @author inspired by G. Grothendieck,
#' \url{https://stackoverflow.com/questions/24702796/outputting-difftime-as-hhmmssmm-in-r}
#'
#' @examples
#' now = Sys.time()
#' after = Sys.time() + 1000
#' \dontrun{fmt(after - now)}
#' \dontrun{fmt(now - after)}

fmt = function(x) {
   if (methods::is(x, "difftime")) {
      units(x) = "secs"
      x = unclass(x)
   }
   y = abs(x)
   sprintf("%s%02d:%02d:%02d:%05.2f",
      ifelse(x < 0, "-", ""),   # sign
      y %/% 86400,              # days
      y %% 86400 %/% 3600,      # hours
      y %% 3600 %/% 60,         # minutes
      y %% 60                   # seconds
   )
}
