#' @title Formats several column in a single column
#'
#' @description
#' `format_address()` This function concatenates a selection of fields from a dataframe. 
#'
#' @param dataset dataframe
#' @param selection vector of colnames to be concatenated
#' 
#' @return The function returns a vector from the concatenation. Each element of the concatenated columns will be separated by a space.
#' 
#' @details The function was created to process the French national address database (BAN) but it can be used to concatenate several columns in any dataframe.
#' 
#' @export
#' 
#' @encoding UTF-8
#' 
#' @examples 
#' 
#' dataset = data.frame(
#'    address_number = c("1", "", "3", "35","", "7"),
#'    address_rep = c("","bis","","ter", "", ""),
#'    address_street = paste("street", LETTERS[1:6]), 
#'    commune_name = c("PARIS", "SETE", "LONDRES", "TOULOUSE", "LYON", "NICE")
#' )
#' dataset
#' 
#' format_address(dataset)
#' format_address(dataset, selection = c("commune_name", "address_street"))

format_address = function(
    dataset,
    selection = c("address_number", "address_rep", "address_street", "commune_name")
) {
    result = sf::st_drop_geometry(dataset[selection])
    result = do.call(paste, result)
    result = gsub("  +", " ", result)
    result = gsub("^ ", "", result)
    result = gsub(" $", "", result)
    return(result)
}

