## In this file are grouped function that are used but should not be exported
#'
#' @title Transform a character vector in logical one
#'
#' @description
#' Use a modality for TRUE and onther for FALSE
#'
#' @param x character vector
#' @param true character, modality for TRUE
#' @param false character, modality for FALSE
#'
#' @return logical vector
#' 
#' @encoding UTF-8
#' @author Victor Champonnois et Frédéric Grelot
#'
#' @examples
#' x = sample(c("red", "blue"), 10, replace = TRUE)
#' floodam.data:::to_logical(x, "red", "blue")
#' floodam.data:::to_logical(x, "red", "green")
 
to_logical =  function(x, true = TRUE, false = FALSE) {
    data.table::fifelse(x == true, TRUE,  data.table::fifelse(x == false, FALSE, NA)) 
}

#' @title Add NA for a given value
#'
#' @param x vector
#' @param value value that shall be replaced by NA
#'
#' @return vector
#' 
#' @encoding UTF-8
#' @author Victor Champonnois et Frédéric Grelot
#'
#' @examples
#' x = sample(c("red", "blue"), 10, replace = TRUE)
#' floodam.data:::treat_na(x, "red")
#' floodam.data:::treat_na(x, "blue")
#' floodam.data:::treat_na(x, "green")
 
treat_na = function(x, value) {
    na.value = switch(EXPR = typeof(x),
        "character" = NA_character_,
        "integer" = NA_integer_,
        "double" = NA_real_,
        NA)
    data.table::fifelse(x == value, na.value, x)
}

#' @title Add information to a journal
#'
#' @description
#' Use a modality for TRUE and onther for FALSE
#'
#' @param ... zero or more objects which can be coerced to character.
#' @param journal character vector, journal
#' @param verbose logical, should x generates a diagnostic message
#' @param first logical, should ... be considered as a first message or a second one preceeded by tabulation
#'
#' @return updated journal
#'
#' @encoding UTF-8
#' @author Frédéric Grelot
#'
#' @examples
#' journal = floodam.data:::add_journal_old("Operation started.")
#' floodam.data:::add_journal_old("No problem occurred.", journal = journal)
#' floodam.data:::add_journal_old("No problem occurred.", journal = journal, verbose = TRUE)
 
add_journal_old = function(..., journal = character(), verbose = FALSE, first = FALSE) {
    args = as.character(unlist(list(...)))
    if (identical(verbose, TRUE)) {
        if (identical(first, FALSE)) message(paste("\t...", args)) else message(args)
    }
    if (identical(first, FALSE)) args = paste("\t", args, sep = "") else args = c(args)
    return(c(journal, args))
}

file_version = function(path, pattern, version = "last") {
    if (is.na(pattern)) return(character())
    decreasing = switch(
        version,
        "old" = FALSE,
        TRUE
    )
    result = utils::head(
        sort(
            list.files(path, pattern, full.names = TRUE, recursive = TRUE),
            decreasing = decreasing
        ),
        1
    )
    return(result)
}