% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/analyse_archive.R
\encoding{UTF-8}
\name{analyse_archive}
\alias{analyse_archive}
\title{Analyse names of archive to get useful infomations.}
\usage{
analyse_archive(x, origin = c("ign", "floodam.data"))
}
\arguments{
\item{x}{character vector}

\item{origin}{character, to choose the format. Only "ign" is available at the
moment.}
}
\value{
either a vector or a matrix depending on the length of x.
}
\description{
The function is set for IGN's names of archive, that should normally be
"well" structured with this scheme :
data-type_version_precision_format_projection_scope_date.ext. Sometimes a
less frequent format is
data-name_version_precision_format_projection_scope_proj_date.ext. In the
latter case, "proj" is given in another format than "projection", but also in
a documented way.

From this structure, an analysis is done to retrieve, the type of data, the
version, the precision (very often it is empty), the format used (something
in "SHP", "GPKG" or "SQL"), the projection (something in "WGS84G", "LAMB93",
"RGAF09UTM20", "UTM22RGFG95", "RGR92UTM40S", "RGM04UTM38S"), the scope (
something in "FRA", "FXX", "GLP", "MTQ", "GUF", "REU", "MYT"), the date (in
the format YYYY-MM-DD), the year (YYYY), the extension, and the name (the
name of the archive without the extension.)

This is also done when the format is the less frequent case, because in this
case, the projection is not given.
}
\examples{
ign = c(
  "ADMIN-EXPRESS-COG_3-1__SHP_LAMB93_FRA_2022-04-15.7z",
  "ADMIN-EXPRESS-COG_3-1__SHP_LAMB93_FRA_2022-04-15.7z.001",
  "ADMIN-EXPRESS-COG_3-1__SHP_LAMB93_FRA_2022-04-15",
  "ADMIN-EXPRESS-COG_3-1__SHP_LAMB93_BAD_2022-04-15",
  "ADMIN-EXPRESS-COG_3-1__SHP_BAD_FRA_2022-04-15",
  "ADMIN-EXPRESS-COG_3-1__BAD_LAMB93_FRA_2022-04-15",
  "ADMIN-EXPRESS-COG_3-1__SHP_LAMB93_FRA",
  "ADMIN-EXPRESS-COG_3-1__SHP_LAMB93_FRA_2022-04-15_toto"
)
analyse_archive(ign)
analyse_archive(rep(ign, 2))

floodam = c(
  "admin-express_2022-04-15",
  "admin-express_2022-04-15.rds",
  "admin-express_commune_2022-04-15",
  "admin-express_D034_2022-04-15",
  "admin-express_commune_D034_2022-04-15",
  "admin-express_D034_commune_2022-04-15",
  "ADMIN-EXPRESS-COG_3-1__SHP_RGAF09UTM20_GLP_2022-04-15.7z"
)
analyse_archive(floodam, "floodam.data")
}
\author{
Frédéric Grelot
}
