% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/download.geo_sirene.R
\name{download.geo_sirene}
\alias{download.geo_sirene}
\title{Download Géo SIRENE}
\usage{
download.geo_sirene(
  destination,
  origin = "cquest",
  name = NULL,
  extension = NULL,
  version = NULL,
  date = NULL,
  month = NULL,
  version_insee = "v2019",
  verbose = TRUE
)
}
\arguments{
\item{destination}{character, the address where dara are stocked.}

\item{origin}{character, either a keyword or the address from where data are downloaded. Best to keep it
at default value. See details.}

\item{name}{character, vector of acceptable names fo archive to be downloaded.}

\item{extension}{character, vector of acceptable types of archive to be downloaded.}

\item{version}{string, version of ADMIN EXPRESS to be downloaded.}

\item{date}{character, date of the archive to be downloaded.}

\item{month}{character, vector of month to be downloaded}

\item{version_insee}{string, INSEE version to be downloaded. Only used with \code{origin = "cquest"}.}

\item{verbose}{logical, should the function send some messages while running.}
}
\value{
nothing
}
\description{
Function used to downlaod Geolocalized SIRENE data-base.
}
\section{Details}{


If \code{origin == "cquest"}, then all necessary variables are filled with those values:
\itemize{
\item \bold{origin} is changed to \url{https://data.cquest.org/geo_sirene}. This url is adapted depending
on version_insee.
\item \bold{version_insee} If value is "v2019", then the version 2019 is dowloaded from
\url{https://data.cquest.org/geo_sirene}.
\item \bold{name} If version is not set to null, then default value is changed to "StockEtablissement_utf8",
which should be the most complete version at France level.
\item \bold{extension} default value is changed to "csv.gz".
\item \bold{month} is used to set something equivalent to date, but directly in origin.
\item \bold{date} is set to null, because conflict may occur with month.
}

If not, everything shall be filled so that \code{download_archive()} can make a successful download.

@export
}

\examples{
\dontrun{
origin = "https://data.cquest.org/geo_sirene"
destination = tempdir()
month = c("2018-11", "2019-05", "2020-03")
download.geo_sirene(origin, destination, month = month)
unlink(destination)
}
}
