% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/download_bd_topo.R
\encoding{UTF-8}
\name{download_bd_topo}
\alias{download_bd_topo}
\title{Download BD TOPO}
\usage{
download_bd_topo(
  destination,
  origin = "ign",
  name = "BDTOPO",
  extension = "7z",
  date = "last",
  type = c("SHP", "GPKG", "SQL"),
  theme = c("TOUSTHEMES", "ADMINISTRATIF", "ADRESSES", "BDADRESSE", "ERP",
    "HYDROGRAPHIE", "TRANSPORT"),
  department = NULL,
  region = NULL,
  verbose = TRUE
)
}
\arguments{
\item{destination}{character, the address where dara are stocked.}

\item{origin}{character, either a keyword or the address from where data are
downloaded. See details.}

\item{name}{character, vector of acceptable names fo archive to be
downloaded. Default to "BDTOPO".}

\item{extension}{character, vector of acceptable types of archive to be
downloaded. Default to "7z".}

\item{date}{character, date of the archive to be downloaded. Default to
"last".}

\item{type}{character, format of GIS data. To be chosen within "SHP", "GPKG",
or "SQL". Default to "SHP".}

\item{theme}{character, themes of BD TOPO to be downloaded when origin is
"ign". See details.}

\item{department}{integer, or converted to integer. Departments that should
be considered. See details.}

\item{region}{integer, or converted to integer. Regions that should be
considered. See details.}

\item{verbose}{logical, should the function send some messages while running.}
}
\value{
nothing
}
\description{
Function used to downlaod BD TOPO. It is a wrapper to
\code{download_archive()}, that helps getting everything fine toi download
aimed archive of BD TOPO from IGN websites.
}
\details{
If \code{origin == "ign"}, then \bold{origin} is changed to
"https://geoservices.ign.fr/bdtopo".

If not, everything shall be filled so that \code{download_archive()} can make a
successful download.
}
\examples{
\dontrun{
destination = tempdir()

# WARNING: download everything that is "new".
download_bd_topo(destination) 

download_bd_topo(destination, department = 34)
download_bd_topo(destination, department = 34, date = "2019-03-15")
download_bd_topo(destination, region = 11, type = "GPKG")

# WARNING: download everything related to D034
download_bd_topo(destination, department = 34, date = NULL)

unlink(destination)
}
}
\author{
Frédéric Grelot
}
