test_that("Test analyse_intersection",
    {
        create_grid = function(ext, res) {
            result = mapply(
                    function(pos, x, y) {
                        i = unlist(pos[1])
                        j = unlist(pos[2])
                        sf::st_polygon(
                            list(
                                matrix(
                                    c(
                                        x[c(i, i + 1, i + 1, i, i)],
                                        y[c(j, j, j + 1, j + 1, j)]
                                    ),
                                    ncol = 2
                                )
                            )
                        )
                    },
                    pos = split(
                        expand.grid(seq(res), seq(res)),
                        seq(res * res)
                    ),
                    MoreArgs = list(
                        x = seq(ext[1], ext[2], length.out = res + 1),
                        y = seq(ext[3], ext[4], length.out = res + 1)
                    ),
                    SIMPLIFY = FALSE
                )
            sf::st_sf(sf::st_sfc(result, crs = 4326)      )
        }
        resolution = 4
        selection = rep_len(
            c(
                rep_len(c(TRUE, FALSE), length.out = resolution),
                rep_len(c(FALSE,TRUE), length.out = resolution)
            ), length.out = resolution^2)
        layer_1 = create_grid(c(0, 1, 44, 45), resolution)[selection, ]
        layer_2 = create_grid(c(0.1, 0.9, 44.1, 44.9), 2 * resolution)
        names(layer_1) = names(layer_2) = "geometry"
        sf::st_geometry(layer_1) = sf::st_geometry(layer_2) = "geometry"

        result = analyse_intersection(layer_2, layer_1)
        expect_success(expect_type(result, "list"))
        expect_success(expect_s3_class(result, "data.frame"))
        expect_success(expect_length(result, 2))
        expect_success(expect_identical(nrow(result), nrow(layer_2)))
        expect_success(expect_identical(names(result), c("intersect", "proportion")))
        expect_success(expect_identical(
            which(!result[["intersect"]]),
            as.integer(c(3, 8, 17, 22, 43, 48, 57, 62))
        ))
        expect_success(expect_identical(
            which(result[["proportion"]] == 0),
            as.integer(
                c( 3,  4,  8, 17, 21, 22, 25, 29, 30,
                  35, 36, 40, 43, 44, 48, 57, 61, 62)
            )
        ))
 
        eaip = analyse_eaip(layer_2, layer_1)
        expect_success(expect_type(eaip, "list"))
        expect_success(expect_s3_class(eaip, "sf"))
        expect_success(expect_length(eaip, 2))
        expect_success(expect_identical(nrow(eaip), nrow(layer_2)))
        expect_success(expect_identical(names(eaip), c("geometry", "eaip")))

        # plot(layer_1, col = rgb(0, 0, 1, .2))
        # plot(layer_2, col = rgb(0, 1, 0, .2), add = TRUE)
        # plot(layer_2[result$intersect, ], col = rgb(0, 1, 0, .2), add = TRUE)
    }
)
