test_that("Test save archive",
    {
        x = data.frame(scope = 0:2)
        temp_dir = tempdir()
        scope = "scope"

        # Expected behaviour without scope
        archive_rds = "rds.rds"
        expect_success(
            expect_invisible(save_archive(x, file.path(temp_dir, archive_rds)))
        )
        expect_success(
            expect_identical(archive_rds %in% dir(temp_dir), TRUE)
        )

        archive_gz = "gz.gz"
        expect_success(
            expect_invisible(
                save_archive(
                    x,
                    file.path(temp_dir, archive_gz),
                    extension = "rds"
                )
            )
        )
        expect_success(
            expect_identical("gz.rds" %in% dir(temp_dir), TRUE)
        )

        archive_base = "basename"
        expect_success(
            expect_invisible(
                save_archive(
                    x,
                    file.path(temp_dir, archive_base),
                    extension = "rds"
                )
            )
        )
        expect_success(
            expect_identical("basename.rds" %in% dir(temp_dir), TRUE)
        )

        # Expected behaviour with scope
        scope_expected = format_scope(x[["scope"]])
        scope_expected = scope_expected[!is.na(scope_expected)]
        basename_expected = sprintf("%s_%s.rds", archive_base, scope_expected)
        expect_warning(
            save_archive(
                x,
                file.path(temp_dir, archive_base),
                extension = "rds",
                scope = "scope"
            ),
            "Some levels of scope ar NA. Corresponding data will not be saved."
        )
        expect_success(
            expect_identical(all(basename_expected %in% dir(temp_dir)), TRUE)
        )
        scope_NA = as.factor(format_scope(x[["scope"]]))
        expect_warning(
            save_archive(
                x,
                file.path(temp_dir, archive_base),
                extension = "rds",
                scope = scope_NA
            ),
            "Some levels of scope ar NA. Corresponding data will not be saved."
        )

        # Expected warnings
        expect_warning(
            save_archive(x, file.path(temp_dir, archive_rds), scope = list()),
            "scope should be a character at this stage. It is removed."
        )
        expect_warning(
            save_archive(x, file.path(temp_dir, archive_base)),
            "Unmanaged extension. Nothing is saved."
        )
        expect_warning(
            save_archive(
                x,
                file.path(temp_dir, archive_rds),
                extension = "unkown"
            ),
            "Unmanaged extension. Nothing is saved."
        )
        expect_warning(
            save_archive(
                x[character(), , drop = FALSE],
                file.path(temp_dir, archive_rds),
                extension = "unkown"
            ),
            "Empty data. Nothing is saved."
        )
    }
)
